# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/block.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.typewriter import inline_pb2 as eolymp_dot_typewriter_dot_inline__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/typewriter/block.proto\x12\x11\x65olymp.typewriter\x1a\x1e\x65olymp/typewriter/inline.proto\"7\n\tContainer\x12*\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x18.eolymp.typewriter.Block\"\xa2\x10\n\x05\x42lock\x12\x37\n\tparagraph\x18\x01 \x01(\x0b\x32\".eolymp.typewriter.Block.ParagraphH\x00\x12\x31\n\x06layout\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Block.LayoutH\x00\x12-\n\x04\x63ode\x18\x03 \x01(\x0b\x32\x1d.eolymp.typewriter.Block.CodeH\x00\x12-\n\x04math\x18\x04 \x01(\x0b\x32\x1d.eolymp.typewriter.Block.MathH\x00\x12/\n\x05image\x18\x05 \x01(\x0b\x32\x1e.eolymp.typewriter.Block.ImageH\x00\x12\x33\n\x07heading\x18\x06 \x01(\x0b\x32 .eolymp.typewriter.Block.HeadingH\x00\x12-\n\x04list\x18\x07 \x01(\x0b\x32\x1d.eolymp.typewriter.Block.ListH\x00\x12/\n\x05\x65mbed\x18\x08 \x01(\x0b\x32\x1e.eolymp.typewriter.Block.EmbedH\x00\x12/\n\x05table\x18\t \x01(\x0b\x32\x1e.eolymp.typewriter.Block.TableH\x00\x12\x31\n\x06widget\x18\n \x01(\x0b\x32\x1f.eolymp.typewriter.Block.WidgetH\x00\x1a\x38\n\tParagraph\x12+\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\xeb\x03\n\x06Layout\x12<\n\tdirection\x18\x01 \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Direction\x12>\n\x0b\x61lign_items\x18\n \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12@\n\ralign_content\x18\x0b \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12@\n\rjustify_items\x18\x0c \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12\x42\n\x0fjustify_content\x18\r \x01(\x0e\x32).eolymp.typewriter.Block.Layout.Alignment\x12\x0b\n\x03gap\x18\x14 \x01(\r\x12\x0f\n\x07padding\x18\x15 \x03(\r\x12.\n\x08\x63hildren\x18\x64 \x03(\x0b\x32\x1c.eolymp.typewriter.Container\" \n\tDirection\x12\x07\n\x03ROW\x10\x00\x12\n\n\x06\x43OLUMN\x10\x01\"+\n\tAlignment\x12\t\n\x05START\x10\x00\x12\n\n\x06\x43\x45NTER\x10\x01\x12\x07\n\x03\x45ND\x10\x02\x1a\xc9\x01\n\x04List\x12\x32\n\x05style\x18\x01 \x01(\x0e\x32#.eolymp.typewriter.Block.List.Style\x12\x34\n\x08\x63hildren\x18\n \x03(\x0b\x32\".eolymp.typewriter.Block.List.Item\x1a\x32\n\x04Item\x12*\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x18.eolymp.typewriter.Block\"#\n\x05Style\x12\r\n\tUNORDERED\x10\x00\x12\x0b\n\x07ORDERED\x10\x01\x1a\x61\n\x05Image\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\x0b\n\x03\x61lt\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\r\x12\x0e\n\x06height\x18\x05 \x01(\r\x12\x10\n\x08zoomable\x18\x06 \x01(\x08\x1a\x45\n\x07Heading\x12\r\n\x05level\x18\x01 \x01(\r\x12+\n\x08\x63hildren\x18\n \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\x17\n\x04Math\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x1a%\n\x04\x43ode\x12\x0c\n\x04lang\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x1aq\n\x05\x45mbed\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x34\n\x06values\x18\x02 \x03(\x0b\x32$.eolymp.typewriter.Block.Embed.Value\x1a$\n\x05Value\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x8e\x02\n\x05Table\x12\x35\n\x06header\x18\x01 \x01(\x0e\x32%.eolymp.typewriter.Block.Table.Header\x12\x34\n\x08\x63hildren\x18\n \x03(\x0b\x32\".eolymp.typewriter.Block.Table.Row\x1a<\n\x03Row\x12\x35\n\x08\x63hildren\x18\x01 \x03(\x0b\x32#.eolymp.typewriter.Block.Table.Cell\x1a\x32\n\x04\x43\x65ll\x12*\n\x08\x63hildren\x18\x01 \x03(\x0b\x32\x18.eolymp.typewriter.Block\"&\n\x06Header\x12\x0e\n\nHORIZONTAL\x10\x00\x12\x0c\n\x08VERTICAL\x10\x01\x1a\xba\x01\n\x06Widget\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\nattributes\x18\x02 \x03(\x0b\x32/.eolymp.typewriter.Block.Widget.AttributesEntry\x12*\n\x08\x63hildren\x18\n \x03(\x0b\x32\x18.eolymp.typewriter.Block\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04nodeB7Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.typewriter.block_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriter'
  _BLOCK_WIDGET_ATTRIBUTESENTRY._options = None
  _BLOCK_WIDGET_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CONTAINER._serialized_start=84
  _CONTAINER._serialized_end=139
  _BLOCK._serialized_start=142
  _BLOCK._serialized_end=2224
  _BLOCK_PARAGRAPH._serialized_start=651
  _BLOCK_PARAGRAPH._serialized_end=707
  _BLOCK_LAYOUT._serialized_start=710
  _BLOCK_LAYOUT._serialized_end=1201
  _BLOCK_LAYOUT_DIRECTION._serialized_start=1124
  _BLOCK_LAYOUT_DIRECTION._serialized_end=1156
  _BLOCK_LAYOUT_ALIGNMENT._serialized_start=1158
  _BLOCK_LAYOUT_ALIGNMENT._serialized_end=1201
  _BLOCK_LIST._serialized_start=1204
  _BLOCK_LIST._serialized_end=1405
  _BLOCK_LIST_ITEM._serialized_start=1318
  _BLOCK_LIST_ITEM._serialized_end=1368
  _BLOCK_LIST_STYLE._serialized_start=1370
  _BLOCK_LIST_STYLE._serialized_end=1405
  _BLOCK_IMAGE._serialized_start=1407
  _BLOCK_IMAGE._serialized_end=1504
  _BLOCK_HEADING._serialized_start=1506
  _BLOCK_HEADING._serialized_end=1575
  _BLOCK_MATH._serialized_start=1577
  _BLOCK_MATH._serialized_end=1600
  _BLOCK_CODE._serialized_start=1602
  _BLOCK_CODE._serialized_end=1639
  _BLOCK_EMBED._serialized_start=1641
  _BLOCK_EMBED._serialized_end=1754
  _BLOCK_EMBED_VALUE._serialized_start=1718
  _BLOCK_EMBED_VALUE._serialized_end=1754
  _BLOCK_TABLE._serialized_start=1757
  _BLOCK_TABLE._serialized_end=2027
  _BLOCK_TABLE_ROW._serialized_start=1875
  _BLOCK_TABLE_ROW._serialized_end=1935
  _BLOCK_TABLE_CELL._serialized_start=1937
  _BLOCK_TABLE_CELL._serialized_end=1987
  _BLOCK_TABLE_HEADER._serialized_start=1989
  _BLOCK_TABLE_HEADER._serialized_end=2027
  _BLOCK_WIDGET._serialized_start=2030
  _BLOCK_WIDGET._serialized_end=2216
  _BLOCK_WIDGET_ATTRIBUTESENTRY._serialized_start=2167
  _BLOCK_WIDGET_ATTRIBUTESENTRY._serialized_end=2216
# @@protoc_insertion_point(module_scope)
