# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/helpdesk/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.helpdesk import document_pb2 as eolymp_dot_helpdesk_dot_document__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/helpdesk/events.proto\x12\x0f\x65olymp.helpdesk\x1a\x1e\x65olymp/helpdesk/document.proto\"C\n\x14\x44ocumentCreatedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"C\n\x14\x44ocumentUpdatedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.Document\"C\n\x14\x44ocumentDeletedEvent\x12+\n\x08\x64ocument\x18\x01 \x01(\x0b\x32\x19.eolymp.helpdesk.DocumentB3Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdeskb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.helpdesk.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/helpdesk;helpdesk'
  _DOCUMENTCREATEDEVENT._serialized_start=81
  _DOCUMENTCREATEDEVENT._serialized_end=148
  _DOCUMENTUPDATEDEVENT._serialized_start=150
  _DOCUMENTUPDATEDEVENT._serialized_end=217
  _DOCUMENTDELETEDEVENT._serialized_start=219
  _DOCUMENTDELETEDEVENT._serialized_end=286
# @@protoc_insertion_point(module_scope)
