# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/workspace.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.workspace import file_pb2 as eolymp_dot_workspace_dot_file__pb2
from eolymp.workspace import project_pb2 as eolymp_dot_workspace_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n eolymp/workspace/workspace.proto\x12\x10\x65olymp.workspace\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1b\x65olymp/workspace/file.proto\x1a\x1e\x65olymp/workspace/project.proto\"?\n\x14\x44\x65scribeProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\"C\n\x15\x44\x65scribeProjectOutput\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"\x87\x01\n\x11ListProjectsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.workspace.ListProjectsInput.Filter\x1a\x17\n\x06\x46ilter\x12\r\n\x05query\x18\x01 \x01(\t\"M\n\x12ListProjectsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.workspace.Project\"@\n\x12\x43reateProjectInput\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\">\n\x13\x43reateProjectOutput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\"i\n\x12UpdateProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\x12*\n\x07project\x18\x03 \x01(\x0b\x32\x19.eolymp.workspace.Project\"\x15\n\x13UpdateProjectOutput\"=\n\x12\x44\x65leteProjectInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteProjectOutput\"W\n\x0eListFilesInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"G\n\x0fListFilesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.workspace.File\"G\n\x11\x44\x65scribeFileInput\x12\x10\n\x08\x66ile_ern\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\":\n\x12\x44\x65scribeFileOutput\x12$\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x16.eolymp.workspace.File\"Y\n\x0fUploadFileInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x13\n\x0bproject_ern\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\"$\n\x10UploadFileOutput\x12\x10\n\x08\x66ile_ern\x18\x01 \x01(\t\"E\n\x0fRemoveFileInput\x12\x10\n\x08\x66ile_ern\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x12\n\x10RemoveFileOutput2\xe6\x0c\n\tWorkspace\x12\xba\x01\n\x0f\x44\x65scribeProject\x12&.eolymp.workspace.DescribeProjectInput\x1a\'.eolymp.workspace.DescribeProjectOutput\"V\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0c\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\n\xf4\x03\x82\xd3\xe4\x93\x02\"\x12 /workspace/projects/{project_id}\x12\xa3\x01\n\x0cListProjects\x12#.eolymp.workspace.ListProjectsInput\x1a$.eolymp.workspace.ListProjectsOutput\"H\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x15\x12\x13/workspace/projects\x12\xa7\x01\n\rCreateProject\x12$.eolymp.workspace.CreateProjectInput\x1a%.eolymp.workspace.CreateProjectOutput\"I\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x15\"\x13/workspace/projects\x12\xb4\x01\n\rUpdateProject\x12$.eolymp.workspace.UpdateProjectInput\x1a%.eolymp.workspace.UpdateProjectOutput\"V\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"\" /workspace/projects/{project_id}\x12\xb4\x01\n\rDeleteProject\x12$.eolymp.workspace.DeleteProjectInput\x1a%.eolymp.workspace.DeleteProjectOutput\"V\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"* /workspace/projects/{project_id}\x12\xad\x01\n\tListFiles\x12 .eolymp.workspace.ListFilesInput\x1a!.eolymp.workspace.ListFilesOutput\"[\x82\xe3\n\x1a\x8a\xe3\n\x16workspace:project:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02(\x12&/workspace/projects/{project_id}/files\x12\xbe\x01\n\x0c\x44\x65scribeFile\x12#.eolymp.workspace.DescribeFileInput\x1a$.eolymp.workspace.DescribeFileOutput\"c\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02/\x12-/workspace/projects/{project_id}/files/{name}\x12\xb1\x01\n\nUploadFile\x12!.eolymp.workspace.UploadFileInput\x1a\".eolymp.workspace.UploadFileOutput\"\\\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02(\"&/workspace/projects/{project_id}/files\x12\xb8\x01\n\nRemoveFile\x12!.eolymp.workspace.RemoveFileInput\x1a\".eolymp.workspace.RemoveFileOutput\"c\x82\xe3\n\x1b\x8a\xe3\n\x17workspace:project:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02/*-/workspace/projects/{project_id}/files/{name}B5Z3github.com/eolymp/go-sdk/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.workspace_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/workspace;workspace'
  _WORKSPACE.methods_by_name['DescribeProject']._options = None
  _WORKSPACE.methods_by_name['DescribeProject']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\014\365\342\n\000\000\240A\370\342\n\364\003\202\323\344\223\002\"\022 /workspace/projects/{project_id}'
  _WORKSPACE.methods_by_name['ListProjects']._options = None
  _WORKSPACE.methods_by_name['ListProjects']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\025\022\023/workspace/projects'
  _WORKSPACE.methods_by_name['CreateProject']._options = None
  _WORKSPACE.methods_by_name['CreateProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002\025\"\023/workspace/projects'
  _WORKSPACE.methods_by_name['UpdateProject']._options = None
  _WORKSPACE.methods_by_name['UpdateProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"\" /workspace/projects/{project_id}'
  _WORKSPACE.methods_by_name['DeleteProject']._options = None
  _WORKSPACE.methods_by_name['DeleteProject']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"* /workspace/projects/{project_id}'
  _WORKSPACE.methods_by_name['ListFiles']._options = None
  _WORKSPACE.methods_by_name['ListFiles']._serialized_options = b'\202\343\n\032\212\343\n\026workspace:project:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002(\022&/workspace/projects/{project_id}/files'
  _WORKSPACE.methods_by_name['DescribeFile']._options = None
  _WORKSPACE.methods_by_name['DescribeFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002/\022-/workspace/projects/{project_id}/files/{name}'
  _WORKSPACE.methods_by_name['UploadFile']._options = None
  _WORKSPACE.methods_by_name['UploadFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002(\"&/workspace/projects/{project_id}/files'
  _WORKSPACE.methods_by_name['RemoveFile']._options = None
  _WORKSPACE.methods_by_name['RemoveFile']._serialized_options = b'\202\343\n\033\212\343\n\027workspace:project:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002/*-/workspace/projects/{project_id}/files/{name}'
  _DESCRIBEPROJECTINPUT._serialized_start=214
  _DESCRIBEPROJECTINPUT._serialized_end=277
  _DESCRIBEPROJECTOUTPUT._serialized_start=279
  _DESCRIBEPROJECTOUTPUT._serialized_end=346
  _LISTPROJECTSINPUT._serialized_start=349
  _LISTPROJECTSINPUT._serialized_end=484
  _LISTPROJECTSINPUT_FILTER._serialized_start=461
  _LISTPROJECTSINPUT_FILTER._serialized_end=484
  _LISTPROJECTSOUTPUT._serialized_start=486
  _LISTPROJECTSOUTPUT._serialized_end=563
  _CREATEPROJECTINPUT._serialized_start=565
  _CREATEPROJECTINPUT._serialized_end=629
  _CREATEPROJECTOUTPUT._serialized_start=631
  _CREATEPROJECTOUTPUT._serialized_end=693
  _UPDATEPROJECTINPUT._serialized_start=695
  _UPDATEPROJECTINPUT._serialized_end=800
  _UPDATEPROJECTOUTPUT._serialized_start=802
  _UPDATEPROJECTOUTPUT._serialized_end=823
  _DELETEPROJECTINPUT._serialized_start=825
  _DELETEPROJECTINPUT._serialized_end=886
  _DELETEPROJECTOUTPUT._serialized_start=888
  _DELETEPROJECTOUTPUT._serialized_end=909
  _LISTFILESINPUT._serialized_start=911
  _LISTFILESINPUT._serialized_end=998
  _LISTFILESOUTPUT._serialized_start=1000
  _LISTFILESOUTPUT._serialized_end=1071
  _DESCRIBEFILEINPUT._serialized_start=1073
  _DESCRIBEFILEINPUT._serialized_end=1144
  _DESCRIBEFILEOUTPUT._serialized_start=1146
  _DESCRIBEFILEOUTPUT._serialized_end=1204
  _UPLOADFILEINPUT._serialized_start=1206
  _UPLOADFILEINPUT._serialized_end=1295
  _UPLOADFILEOUTPUT._serialized_start=1297
  _UPLOADFILEOUTPUT._serialized_end=1333
  _REMOVEFILEINPUT._serialized_start=1335
  _REMOVEFILEINPUT._serialized_end=1404
  _REMOVEFILEOUTPUT._serialized_start=1406
  _REMOVEFILEOUTPUT._serialized_end=1424
  _WORKSPACE._serialized_start=1427
  _WORKSPACE._serialized_end=3065
# @@protoc_insertion_point(module_scope)
