# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/member.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.community import attribute_pb2 as eolymp_dot_community_dot_attribute__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/community/member.proto\x12\x10\x65olymp.community\x1a!eolymp/annotations/resource.proto\x1a eolymp/community/attribute.proto\"\xf3\x05\n\x06Member\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12\x12\n\nregistered\x18\x04 \x01(\x08\x12\x0f\n\x07staffed\x18\x05 \x01(\x08\x12\r\n\x05ghost\x18\x07 \x01(\x08\x12\x1a\n\x12out_of_competition\x18\x08 \x01(\x08\x12/\n\x06status\x18\x06 \x01(\x0e\x32\x1f.eolymp.community.Member.Status\x12\x35\n\nidentities\x18\n \x03(\x0b\x32!.eolymp.community.Member.Identity\x12.\n\x06values\x18\x14 \x03(\x0b\x32\x1e.eolymp.community.Member.Value\x1a\xb2\x01\n\x08Identity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06issuer\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08nickname\x18\x05 \x01(\t\x12\x0f\n\x07picture\x18\x06 \x01(\t\x12\r\n\x05\x65mail\x18\x07 \x01(\t\x12\x16\n\x0e\x65mail_verified\x18\x08 \x01(\x08\x12\x0f\n\x07profile\x18\t \x01(\t\x12\x10\n\x08password\x18\x64 \x01(\t\x1a\x84\x01\n\x05Value\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12\x38\n\x0e\x61ttribute_type\x18\x02 \x01(\x0e\x32 .eolymp.community.Attribute.Type\x12\x14\n\x0cvalue_string\x18\n \x01(\t\x12\x14\n\x0cvalue_number\x18\x0b \x01(\x05\"b\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\r\n\tUNSTAFFED\x10\x01\x12\x10\n\x0cUNREGISTERED\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08INACTIVE\x10\x04\x12\t\n\x05GHOST\x10\x05:\'\xb2\xe3\n#\xba\xe3\n\x06member\xc2\xe3\n\x15\x65olymp.universe.SpaceB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _MEMBER._options = None
  _MEMBER._serialized_options = b'\262\343\n#\272\343\n\006member\302\343\n\025eolymp.universe.Space'
  _MEMBER._serialized_start=121
  _MEMBER._serialized_end=876
  _MEMBER_IDENTITY._serialized_start=422
  _MEMBER_IDENTITY._serialized_end=600
  _MEMBER_VALUE._serialized_start=603
  _MEMBER_VALUE._serialized_end=735
  _MEMBER_STATUS._serialized_start=737
  _MEMBER_STATUS._serialized_end=835
# @@protoc_insertion_point(module_scope)
