# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.workspace import project_pb2 as eolymp_dot_workspace_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/workspace/events.proto\x12\x10\x65olymp.workspace\x1a\x1e\x65olymp/workspace/project.proto\"A\n\x13ProjectCreatedEvent\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"A\n\x13ProjectUpdatedEvent\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.Project\"A\n\x13ProjectDeletedEvent\x12*\n\x07project\x18\x01 \x01(\x0b\x32\x19.eolymp.workspace.ProjectB5Z3github.com/eolymp/go-sdk/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/workspace;workspace'
  _PROJECTCREATEDEVENT._serialized_start=83
  _PROJECTCREATEDEVENT._serialized_end=148
  _PROJECTUPDATEDEVENT._serialized_start=150
  _PROJECTUPDATEDEVENT._serialized_end=215
  _PROJECTDELETEDEVENT._serialized_start=217
  _PROJECTDELETEDEVENT._serialized_end=282
# @@protoc_insertion_point(module_scope)
