# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/category.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65olymp/atlas/category.proto\x12\x0c\x65olymp.atlas\"\xd1\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07visible\x18\n \x01(\x08\x12\r\n\x05index\x18\x0b \x01(\r\x12\x11\n\tparent_id\x18\x0c \x01(\t\x12\r\n\x05image\x18\x14 \x01(\t\x12\x38\n\x0c\x64\x65scriptions\x18\x1e \x03(\x0b\x32\".eolymp.atlas.Category.Description\x1a=\n\x0b\x44\x65scription\x12\x0e\n\x06locale\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\tB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.category_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CATEGORY._serialized_start=46
  _CATEGORY._serialized_end=255
  _CATEGORY_DESCRIPTION._serialized_start=194
  _CATEGORY_DESCRIPTION._serialized_end=255
# @@protoc_insertion_point(module_scope)
