# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/statement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.typewriter import block_pb2 as eolymp_dot_typewriter_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65olymp/atlas/statement.proto\x12\x0c\x65olymp.atlas\x1a!eolymp/annotations/resource.proto\x1a\x1d\x65olymp/typewriter/block.proto\"\xe0\x02\n\tStatement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0e\n\x06locale\x18\x03 \x01(\t\x12\r\n\x05title\x18\x04 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x05 \x01(\t\x12\x32\n\x0c\x63ontent_rich\x18\x08 \x01(\x0b\x32\x1c.eolymp.typewriter.Container\x12\x15\n\rdownload_link\x18\x07 \x01(\t\x12.\n\x06\x66ormat\x18\x06 \x01(\x0e\x32\x1e.eolymp.atlas.Statement.Format\x12\x0e\n\x06\x61uthor\x18\x65 \x01(\t\x12\x0e\n\x06source\x18\x66 \x01(\t\"=\n\x06\x46ormat\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03TEX\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02\x12\x08\n\x04HTML\x10\x03\x12\x08\n\x04RICH\x10\x04:)\xb2\xe3\n%\xba\xe3\n\tstatement\xc2\xe3\n\x14\x65olymp.atlas.ProblemB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.statement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _STATEMENT._options = None
  _STATEMENT._serialized_options = b'\262\343\n%\272\343\n\tstatement\302\343\n\024eolymp.atlas.Problem'
  _STATEMENT._serialized_start=113
  _STATEMENT._serialized_end=465
  _STATEMENT_FORMAT._serialized_start=361
  _STATEMENT_FORMAT._serialized_end=422
# @@protoc_insertion_point(module_scope)
