# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/workspace/project.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/workspace/project.proto\x12\x10\x65olymp.workspace\x1a!eolymp/annotations/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb7\x03\n\x07Project\x12\x0c\n\x03\x65rn\x18\x8fN \x01(\t\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07runtime\x18\x03 \x01(\t\x12\x38\n\nvisibility\x18\x04 \x01(\x0e\x32$.eolymp.workspace.Project.Visibility\x12\x11\n\tauthor_id\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x06target\x18\n \x01(\x0b\x32 .eolymp.workspace.Project.Target\x12\x12\n\ntarget_ern\x18\x0b \x01(\t\x12\x0e\n\x06labels\x18\x64 \x03(\t\x1a.\n\x06Target\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"/\n\nVisibility\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\n\n\x06PUBLIC\x10\x02:\x0f\xb2\xe3\n\x0b\xba\xe3\n\x07projectB5Z3github.com/eolymp/go-sdk/eolymp/workspace;workspaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.workspace.project_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/workspace;workspace'
  _PROJECT._options = None
  _PROJECT._serialized_options = b'\262\343\n\013\272\343\n\007project'
  _PROJECT._serialized_start=121
  _PROJECT._serialized_end=560
  _PROJECT_TARGET._serialized_start=448
  _PROJECT_TARGET._serialized_end=494
  _PROJECT_VISIBILITY._serialized_start=496
  _PROJECT_VISIBILITY._serialized_end=543
# @@protoc_insertion_point(module_scope)
