# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/typewriter/inline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/typewriter/inline.proto\x12\x11\x65olymp.typewriter\"\xdc\x04\n\x06Inline\x12.\n\x04text\x18\x01 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.TextH\x00\x12.\n\x04link\x18\x02 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.LinkH\x00\x12.\n\x04math\x18\x03 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.MathH\x00\x12.\n\x04\x63ode\x18\x04 \x01(\x0b\x32\x1e.eolymp.typewriter.Inline.CodeH\x00\x12\x36\n\x08variable\x18\x05 \x01(\x0b\x32\".eolymp.typewriter.Inline.VariableH\x00\x1aO\n\x05Style\x12\x0c\n\x04\x62old\x18\x01 \x01(\x08\x12\x0e\n\x06italic\x18\x02 \x01(\x08\x12\x11\n\tunderline\x18\x03 \x01(\x08\x12\x15\n\rstrikethrough\x18\x04 \x01(\x08\x1a\x43\n\x04Text\x12\x0b\n\x03str\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.Style\x1a@\n\x04Link\x12\x0b\n\x03url\x18\x01 \x01(\t\x12+\n\x08\x63hildren\x18\n \x03(\x0b\x32\x19.eolymp.typewriter.Inline\x1a\x17\n\x04Math\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1a\x17\n\x04\x43ode\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x1aH\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05style\x18\x02 \x01(\x0b\x32\x1f.eolymp.typewriter.Inline.StyleB\x06\n\x04nodeB7Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriterb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.typewriter.inline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/typewriter;typewriter'
  _INLINE._serialized_start=54
  _INLINE._serialized_end=658
  _INLINE_STYLE._serialized_start=312
  _INLINE_STYLE._serialized_end=391
  _INLINE_TEXT._serialized_start=393
  _INLINE_TEXT._serialized_end=460
  _INLINE_LINK._serialized_start=462
  _INLINE_LINK._serialized_end=526
  _INLINE_MATH._serialized_start=528
  _INLINE_MATH._serialized_end=551
  _INLINE_CODE._serialized_start=553
  _INLINE_CODE._serialized_end=576
  _INLINE_VARIABLE._serialized_start=578
  _INLINE_VARIABLE._serialized_end=650
# @@protoc_insertion_point(module_scope)
