# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/entitlement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/judge/entitlement.proto\x12\x0c\x65olymp.judge*\xff\x02\n\x0b\x45ntitlement\x12\x08\n\x04NONE\x10\x00\x12\x12\n\x0e\x43REATE_CONTEST\x10\x01\x12\x12\n\x0eLOOKUP_CONTEST\x10\x02\x12\x12\n\x0eMANAGE_CONTEST\x10\x03\x12\x10\n\x0cVIEW_RUNTIME\x10\x04\x12\x1a\n\x16VIEW_REGISTRATION_FORM\x10\x05\x12\x14\n\x10VIEW_PARTICIPANT\x10\x06\x12\x16\n\x12MANAGE_PARTICIPANT\x10\x07\x12\x10\n\x0cVIEW_PROBLEM\x10\x08\x12\x12\n\x0eMANAGE_PROBLEM\x10\t\x12\x15\n\x11\x43REATE_SUBMISSION\x10\n\x12\x13\n\x0fVIEW_SUBMISSION\x10\x0b\x12\x15\n\x11MANAGE_SUBMISSION\x10\x0c\x12\x15\n\x11VIEW_ANNOUNCEMENT\x10\r\x12\x17\n\x13MANAGE_ANNOUNCEMENT\x10\x0e\x12\x11\n\rCREATE_TICKET\x10\x0f\x12\x0f\n\x0bVIEW_TICKET\x10\x10\x12\x11\n\rMANAGE_TICKET\x10\x11\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.entitlement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _ENTITLEMENT._serialized_start=49
  _ENTITLEMENT._serialized_end=432
# @@protoc_insertion_point(module_scope)
