# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/change.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import resource_pb2 as eolymp_dot_annotations_dot_resource__pb2
from eolymp.atlas import attachment_pb2 as eolymp_dot_atlas_dot_attachment__pb2
from eolymp.atlas import permission_pb2 as eolymp_dot_atlas_dot_permission__pb2
from eolymp.atlas import problem_pb2 as eolymp_dot_atlas_dot_problem__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2
from eolymp.atlas import template_pb2 as eolymp_dot_atlas_dot_template__pb2
from eolymp.atlas import test_pb2 as eolymp_dot_atlas_dot_test__pb2
from eolymp.atlas import testset_pb2 as eolymp_dot_atlas_dot_testset__pb2
from eolymp.executor import interactor_pb2 as eolymp_dot_executor_dot_interactor__pb2
from eolymp.executor import verifier_pb2 as eolymp_dot_executor_dot_verifier__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65olymp/atlas/change.proto\x12\x0c\x65olymp.atlas\x1a!eolymp/annotations/resource.proto\x1a\x1d\x65olymp/atlas/attachment.proto\x1a\x1d\x65olymp/atlas/permission.proto\x1a\x1a\x65olymp/atlas/problem.proto\x1a\x1c\x65olymp/atlas/statement.proto\x1a\x1b\x65olymp/atlas/template.proto\x1a\x17\x65olymp/atlas/test.proto\x1a\x1a\x65olymp/atlas/testset.proto\x1a eolymp/executor/interactor.proto\x1a\x1e\x65olymp/executor/verifier.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe7\x18\n\x06\x43hange\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x12\n\nproblem_id\x18\x05 \x01(\t\x12<\n\x0e\x63reate_problem\x18\x64 \x01(\x0b\x32\".eolymp.atlas.Change.CreateProblemH\x00\x12<\n\x0eupdate_problem\x18\x65 \x01(\x0b\x32\".eolymp.atlas.Change.UpdateProblemH\x00\x12>\n\x0fupdate_verifier\x18\x66 \x01(\x0b\x32#.eolymp.atlas.Change.UpdateVerifierH\x00\x12\x42\n\x11update_interactor\x18h \x01(\x0b\x32%.eolymp.atlas.Change.UpdateInteractorH\x00\x12<\n\x0e\x64\x65lete_problem\x18i \x01(\x0b\x32\".eolymp.atlas.Change.DeleteProblemH\x00\x12@\n\x10\x63reate_statement\x18n \x01(\x0b\x32$.eolymp.atlas.Change.CreateStatementH\x00\x12@\n\x10update_statement\x18o \x01(\x0b\x32$.eolymp.atlas.Change.UpdateStatementH\x00\x12@\n\x10\x64\x65lete_statement\x18p \x01(\x0b\x32$.eolymp.atlas.Change.DeleteStatementH\x00\x12<\n\x0e\x63reate_testset\x18x \x01(\x0b\x32\".eolymp.atlas.Change.CreateTestsetH\x00\x12<\n\x0eupdate_testset\x18y \x01(\x0b\x32\".eolymp.atlas.Change.UpdateTestsetH\x00\x12<\n\x0e\x64\x65lete_testset\x18z \x01(\x0b\x32\".eolymp.atlas.Change.DeleteTestsetH\x00\x12\x37\n\x0b\x63reate_test\x18\x82\x01 \x01(\x0b\x32\x1f.eolymp.atlas.Change.CreateTestH\x00\x12\x37\n\x0bupdate_test\x18\x83\x01 \x01(\x0b\x32\x1f.eolymp.atlas.Change.UpdateTestH\x00\x12\x37\n\x0b\x64\x65lete_test\x18\x84\x01 \x01(\x0b\x32\x1f.eolymp.atlas.Change.DeleteTestH\x00\x12?\n\x0f\x63reate_template\x18\x8c\x01 \x01(\x0b\x32#.eolymp.atlas.Change.CreateTemplateH\x00\x12?\n\x0fupdate_template\x18\x8d\x01 \x01(\x0b\x32#.eolymp.atlas.Change.UpdateTemplateH\x00\x12?\n\x0f\x64\x65lete_template\x18\x8e\x01 \x01(\x0b\x32#.eolymp.atlas.Change.DeleteTemplateH\x00\x12\x43\n\x11\x63reate_attachment\x18\xa0\x01 \x01(\x0b\x32%.eolymp.atlas.Change.CreateAttachmentH\x00\x12\x43\n\x11update_attachment\x18\xa1\x01 \x01(\x0b\x32%.eolymp.atlas.Change.UpdateAttachmentH\x00\x12\x43\n\x11\x64\x65lete_attachment\x18\xa2\x01 \x01(\x0b\x32%.eolymp.atlas.Change.DeleteAttachmentH\x00\x12\x41\n\x10grant_permission\x18\x96\x01 \x01(\x0b\x32$.eolymp.atlas.Change.GrantPermissionH\x00\x12\x43\n\x11revoke_permission\x18\x97\x01 \x01(\x0b\x32%.eolymp.atlas.Change.RevokePermissionH\x00\x1a\x35\n\rCreateProblem\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x1a\\\n\rUpdateProblem\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x1a\x65\n\x0eUpdateVerifier\x12)\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x12(\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x19.eolymp.executor.Verifier\x1ak\n\x10UpdateInteractor\x12+\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x12*\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x1b.eolymp.executor.Interactor\x1a\x36\n\rDeleteProblem\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Problem\x1a\x39\n\x0f\x43reateStatement\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x1a\x62\n\x0fUpdateStatement\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x12&\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x1a:\n\x0f\x44\x65leteStatement\x12\'\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x1a\x35\n\rCreateTestset\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x1a\\\n\rUpdateTestset\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x12$\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x1a\x36\n\rDeleteTestset\x12%\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\x1a/\n\nCreateTest\x12!\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\x1aS\n\nUpdateTest\x12\"\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\x12!\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x12.eolymp.atlas.Test\x1a\x30\n\nDeleteTest\x12\"\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\x1a\x37\n\x0e\x43reateTemplate\x12%\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\x1a_\n\x0eUpdateTemplate\x12&\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\x12%\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x16.eolymp.atlas.Template\x1a\x38\n\x0e\x44\x65leteTemplate\x12&\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x16.eolymp.atlas.Template\x1a;\n\x10\x43reateAttachment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Attachment\x1a\x65\n\x10UpdateAttachment\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Attachment\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Attachment\x1a<\n\x10\x44\x65leteAttachment\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Attachment\x1a:\n\x0fGrantPermission\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Permission\x1a<\n\x10RevokePermission\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Permission:*\xb2\xe3\n&\xba\xe3\n\nattachment\xc2\xe3\n\x14\x65olymp.atlas.ProblemB\t\n\x07payloadB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.change_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _CHANGE._options = None
  _CHANGE._serialized_options = b'\262\343\n&\272\343\n\nattachment\302\343\n\024eolymp.atlas.Problem'
  _CHANGE._serialized_start=380
  _CHANGE._serialized_end=3555
  _CHANGE_CREATEPROBLEM._serialized_start=1917
  _CHANGE_CREATEPROBLEM._serialized_end=1970
  _CHANGE_UPDATEPROBLEM._serialized_start=1972
  _CHANGE_UPDATEPROBLEM._serialized_end=2064
  _CHANGE_UPDATEVERIFIER._serialized_start=2066
  _CHANGE_UPDATEVERIFIER._serialized_end=2167
  _CHANGE_UPDATEINTERACTOR._serialized_start=2169
  _CHANGE_UPDATEINTERACTOR._serialized_end=2276
  _CHANGE_DELETEPROBLEM._serialized_start=2278
  _CHANGE_DELETEPROBLEM._serialized_end=2332
  _CHANGE_CREATESTATEMENT._serialized_start=2334
  _CHANGE_CREATESTATEMENT._serialized_end=2391
  _CHANGE_UPDATESTATEMENT._serialized_start=2393
  _CHANGE_UPDATESTATEMENT._serialized_end=2491
  _CHANGE_DELETESTATEMENT._serialized_start=2493
  _CHANGE_DELETESTATEMENT._serialized_end=2551
  _CHANGE_CREATETESTSET._serialized_start=2553
  _CHANGE_CREATETESTSET._serialized_end=2606
  _CHANGE_UPDATETESTSET._serialized_start=2608
  _CHANGE_UPDATETESTSET._serialized_end=2700
  _CHANGE_DELETETESTSET._serialized_start=2702
  _CHANGE_DELETETESTSET._serialized_end=2756
  _CHANGE_CREATETEST._serialized_start=2758
  _CHANGE_CREATETEST._serialized_end=2805
  _CHANGE_UPDATETEST._serialized_start=2807
  _CHANGE_UPDATETEST._serialized_end=2890
  _CHANGE_DELETETEST._serialized_start=2892
  _CHANGE_DELETETEST._serialized_end=2940
  _CHANGE_CREATETEMPLATE._serialized_start=2942
  _CHANGE_CREATETEMPLATE._serialized_end=2997
  _CHANGE_UPDATETEMPLATE._serialized_start=2999
  _CHANGE_UPDATETEMPLATE._serialized_end=3094
  _CHANGE_DELETETEMPLATE._serialized_start=3096
  _CHANGE_DELETETEMPLATE._serialized_end=3152
  _CHANGE_CREATEATTACHMENT._serialized_start=3154
  _CHANGE_CREATEATTACHMENT._serialized_end=3213
  _CHANGE_UPDATEATTACHMENT._serialized_start=3215
  _CHANGE_UPDATEATTACHMENT._serialized_end=3316
  _CHANGE_DELETEATTACHMENT._serialized_start=3318
  _CHANGE_DELETEATTACHMENT._serialized_end=3378
  _CHANGE_GRANTPERMISSION._serialized_start=3380
  _CHANGE_GRANTPERMISSION._serialized_end=3438
  _CHANGE_REVOKEPERMISSION._serialized_start=3440
  _CHANGE_REVOKEPERMISSION._serialized_end=3500
# @@protoc_insertion_point(module_scope)
